==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXHostsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub BEGIN{no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXHostsManager::put{package NXHostsManager;no warnings;return (__put (@_));}sub 
NXHostsManager::del{package NXHostsManager;no warnings;return (__del (@_));}sub 
NXHostsManager::list{package NXHostsManager;no warnings;return (show (@_));}sub 
NXHostsManager::edit{package NXHostsManager;no warnings;return (__edit (@_));}
sub NXHostsManager::show{package NXHostsManager;no warnings;(my (@hosts)=__list 
(@_));main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (
main::nxgetSTDOUT (),
"\x43\x6c\x69\x65\x6e\x74\x20\x49\x50\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x52\x65\x64\x69\x72\x65\x63\x74\x65\x64\x20\x74\x6f\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x4d\x6f\x64\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),("\x2d" x (0x0309+ 1865-0x0a34)),"\x20",(
"\x2d" x (0x0866+ 4081-0x1839)),"\x20",("\x2d" x (0x00b9+ 7658-0x1e8e)),"\x0a");
foreach my $host (@hosts){chomp ($host);($host=~ s/\r//g );(my ($client,
$redirect,$auth)=split ( /,/ ,$host,(0x03c1+ 8490-0x24e7)));($client=sprintf (
"\x25\x2d\x33\x30\x73",$client));($redirect=sprintf ("\x25\x2d\x33\x30\x73",
$redirect));($auth=sprintf ("\x25\x2d\x32\x31\x73",($auth.
"\x20\x61\x75\x74\x68\x65\x6e\x74\x69\x63\x61\x74\x69\x6f\x6e")));main::nxwrite 
(main::nxgetSTDOUT (),((((($client."\x20").$redirect)."\x20").$auth)."\x0a"));}
main::nxwrite (main::nxgetSTDOUT (),"\x0a");}sub NXHostsManager::__put{package 
NXHostsManager;no warnings;(my (@fields)=@_);NXRedis::sendToDb (((((((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$fields[(0x07ca+ 7705-0x25e3)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x0a64+ 3870-0x1982)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x193f+ 1307-0x1e59)])."\x3a").$fields[(0x1020+ 3205-0x1ca3)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$fields[(0x1038+ 4676-0x2279)])."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$fields[(0x13b5+ 3003-0x1f70)])."\x0a"));return ((0x1937+ 200-0x19fe));}sub 
NXHostsManager::__del{package NXHostsManager;no warnings;(my $clientIpToDelete=
shift (@_));if (checkClientRedirectExist ($clientIpToDelete)){NXRedis::sendToDb 
(((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$clientIpToDelete)."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToDelete)."\x0a"));return ((0x2027+ 1042-0x2438));}else{return (
(0x0119+ 1933-0x08a6));}}sub NXHostsManager::__list{package NXHostsManager;no 
warnings;(my $clientIpToFind=shift (@_));(my (@hosts)=());if ($clientIpToFind){
NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToFind).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}else{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x0a"
);(my (@hostList)=split ( / / ,NXRedis::get (),(0x019d+ 3538-0x0f6f)));foreach 
$host (@hostList){NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$host).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}}return (
@hosts);}sub NXHostsManager::__edit{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $host=shift (@_));(my $port=shift (@_));(my $switch=shift (@_))
;if (checkClientRedirectExist ($client)){if ((defined ($host)and defined ($port)
)){NXRedis::sendToDbAndSave (((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$host)."\x3a").$port)."\x0a"));}if (defined ($switch)){
NXRedis::sendToDbAndSave (((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$switch)."\x0a"));}}NXMsg::send_response (
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",$client);return (
(0x0be8+ 153-0x0c80));}sub NXHostsManager::checkClientRedirectExist{package 
NXHostsManager;no warnings;(my $client=shift (@_));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x65\x78\x69\x73\x74\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client)."\x0a"));(my $result=NXRedis::get ());if (($result==
(0x1df6+ 607-0x2054))){Logger::debug ((("\x48\x6f\x73\x74\x3a\x20\x27".$client).
"\x27\x20\x65\x78\x69\x73\x74\x73\x2e"));}return ($result);}sub 
NXHostsManager::getClientRedirectBeforeAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x175c+ 1151-0x1bda)));}sub 
NXHostsManager::getClientRedirectAfterAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x0930+ 5754-0x1faa)));}sub 
NXHostsManager::__getClientRedirect{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $authbeforelogin=shift (@_));my (@hostTab);my (@ipTab);(my $all
=(0x006d+ 2766-0x0b3b));if (NXLicense::isNotRedirectFeature ()){return (
(0x02c6+ 7846-0x216c));}(my (@hostlist)=__list ());foreach my $hostline (
@hostlist){($hostline=~ s/\n//g );(my (@line)=split ( /,/ ,$hostline,
(0x00a6+ 7127-0x1c7d)));if ((($line[(0x0f3b+ 703-0x11fa)]eq "\x2a")or ($line[
(0x18b6+ 404-0x1a4a)]eq "\x2a\x2e\x2a\x2e\x2a\x2e\x2a"))){if ((($authbeforelogin
 and ($line[(0x12f0+ 130-0x1370)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not (
$authbeforelogin))and ($line[(0x0b04+ 5547-0x20ad)]eq "\x61\x66\x74\x65\x72"))))
{($all=$line[(0x2504+ 293-0x2628)]);}}elsif (($line[(0x1463+ 282-0x157d)]=~ /^[0-9\*\.]{1,15}$/ )
){if ((($authbeforelogin and ($line[(0x0059+ 9197-0x2444)]eq 
"\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin))and ($line[
(0x0660+ 5125-0x1a63)]eq "\x61\x66\x74\x65\x72")))){push (@ipTab,[$line[
(0x11ca+ 5043-0x257d)],$line[(0x0723+ 2830-0x1230)],$line[(0x0534+ 3220-0x11c6)]
]);}}else{if ((($authbeforelogin and ($line[(0x2560+ 328-0x26a6)]eq 
"\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin))and ($line[
(0x04c4+ 2738-0x0f74)]eq "\x61\x66\x74\x65\x72")))){push (@hostTab,[$line[
(0x00ac+ 4900-0x13d0)],$line[(0x0253+ 2203-0x0aed)],$line[(0x079a+ 1330-0x0cca)]
]);}}}(my $regEx=(""));foreach my $ipLine (@ipTab){(my (@pieces)=split ( /\./ ,@
{$ipLine;}[(0x1459+ 2625-0x1e9a)],(-(0x03f6+ 1937-0x0b86))));(my $piecesCount=
scalar (@pieces));($regEx=@{$ipLine;}[(0x0001+ 6832-0x1ab1)]);if (($piecesCount<
(0x074b+ 7930-0x2641))){if (($pieces[(0x0744+ 365-0x08b1)]=~ /^\*/ )){($regEx=(
"\x2e\x7b\x30\x2c\x7d".$regEx));}if (($pieces[$piecesCount-(0x1938+ 387-0x1aba)]
=~ /\*$/ )){($regEx.="\x2e\x7b\x30\x2c\x7d");}}($regEx=~ s/\*/(|[0-9]|[0-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])/g )
;if (($client=~ /^($regEx)$/ )){return (@{$ipLine;}[(0x0a09+ 2757-0x14cd)]);}}
foreach my $hostLine (@hostTab){(my (@ipdata)=split ( /\./ ,$client,
(0x07a9+ 5670-0x1dcf)));(my $ippacked=pack ("\x43\x34",@ipdata));(my $host=
gethostbyaddr ($ippacked,(0x0685+ 284-0x079f)));if ((@{$hostLine;}[
(0x0037+ 3489-0x0dd8)]=~ /^\*/ )){(@{$hostLine;}[(0x0cab+ 4898-0x1fcd)]=~ s/^\*// )
;}else{(@{$hostLine;}[(0x0bac+ 2598-0x15d2)]=("\x5e".@{$hostLine;}[
(0x028d+ 996-0x0671)]));}if ((@{$hostLine;}[(0x1ee6+ 433-0x2097)]=~ /\*$/ )){(@{
$hostLine;}[(0x003b+ 5162-0x1465)]=~ s/\*$// );}else{(@{$hostLine;}[
(0x10eb+ 3987-0x207e)]=(@{$hostLine;}[(0x0d51+ 3923-0x1ca4)]."\x24"));}if ((
$host=~ @{$hostLine;}[0] )){return (@{$hostLine;}[(0x1f1b+ 445-0x20d7)]);}}if (
$all){return ($all);}Logger::debug (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x66\x6f\x75\x6e\x64\x20\x63\x6c\x69\x65\x6e\x74\x20\x49\x50\x3a\x20\x27"
.$client)."\x27\x20\x69\x6e\x20\x68\x6f\x73\x74\x73\x2e\x64\x62\x2e"));return (
(0x04d0+ 1316-0x09f4));}package NXHostsManager;no warnings;
NXMsg::register_response (
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",(0x0ac7+ 7190-0x264e));
"\x3f\x3f\x3f";

==> nomachine-8.3.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXHostsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub BEGIN{no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXHostsManager::put{package NXHostsManager;no warnings;return (__put (@_));}sub 
NXHostsManager::del{package NXHostsManager;no warnings;return (__del (@_));}sub 
NXHostsManager::list{package NXHostsManager;no warnings;return (show (@_));}sub 
NXHostsManager::edit{package NXHostsManager;no warnings;return (__edit (@_));}
sub NXHostsManager::show{package NXHostsManager;no warnings;(my (@hosts)=__list 
(@_));main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (
main::nxgetSTDOUT (),
"\x43\x6c\x69\x65\x6e\x74\x20\x49\x50\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x52\x65\x64\x69\x72\x65\x63\x74\x65\x64\x20\x74\x6f\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x4d\x6f\x64\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),("\x2d" x (0x0072+  49-0x0085)),"\x20",(
"\x2d" x (0x11b3+ 949-0x154a)),"\x20",("\x2d" x (0x06ab+ 3174-0x12fc)),"\x0a");
foreach my $host (@hosts){chomp ($host);($host=~ s/\r//g );(my ($client,
$redirect,$auth)=split ( /,/ ,$host,(0x05d3+ 8007-0x2516)));($client=sprintf (
"\x25\x2d\x33\x30\x73",$client));($redirect=sprintf ("\x25\x2d\x33\x30\x73",
$redirect));($auth=sprintf ("\x25\x2d\x32\x31\x73",($auth.
"\x20\x61\x75\x74\x68\x65\x6e\x74\x69\x63\x61\x74\x69\x6f\x6e")));main::nxwrite 
(main::nxgetSTDOUT (),((((($client."\x20").$redirect)."\x20").$auth)."\x0a"));}
main::nxwrite (main::nxgetSTDOUT (),"\x0a");}sub NXHostsManager::__put{package 
NXHostsManager;no warnings;(my (@fields)=@_);NXRedis::sendToDb (((((((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$fields[(0x0688+ 5832-0x1d50)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x19f1+  68-0x1a35)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x033f+ 1469-0x08fb)])."\x3a").$fields[(0x0502+ 8179-0x24f3)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$fields[(0x1d01+ 1266-0x21f0)])."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$fields[(0x0a6a+ 4908-0x1d96)])."\x0a"));return ((0x1d75+ 1882-0x24ce));}sub 
NXHostsManager::__del{package NXHostsManager;no warnings;(my $clientIpToDelete=
shift (@_));if (checkClientRedirectExist ($clientIpToDelete)){NXRedis::sendToDb 
(((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$clientIpToDelete)."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToDelete)."\x0a"));return ((0x08a9+ 807-0x0bcf));}else{return (
(0x099f+ 5464-0x1ef7));}}sub NXHostsManager::__list{package NXHostsManager;no 
warnings;(my $clientIpToFind=shift (@_));(my (@hosts)=());if ($clientIpToFind){
NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToFind).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}else{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x0a"
);(my (@hostList)=split ( / / ,NXRedis::get (),(0x0158+ 4838-0x143e)));foreach 
$host (@hostList){NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$host).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}}return (
@hosts);}sub NXHostsManager::__edit{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $host=shift (@_));(my $port=shift (@_));(my $switch=shift (@_))
;if (checkClientRedirectExist ($client)){if ((defined ($host)and defined ($port)
)){NXRedis::sendToDbAndSave (((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$host)."\x3a").$port)."\x0a"));}if (defined ($switch)){
NXRedis::sendToDbAndSave (((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$switch)."\x0a"));}}NXMsg::send_response (
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",$client);return (
(0x11fd+ 5275-0x2697));}sub NXHostsManager::checkClientRedirectExist{package 
NXHostsManager;no warnings;(my $client=shift (@_));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x65\x78\x69\x73\x74\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client)."\x0a"));(my $result=NXRedis::get ());if (($result==
(0x13ac+ 791-0x16c2))){Logger::debug ((("\x48\x6f\x73\x74\x3a\x20\x27".$client).
"\x27\x20\x65\x78\x69\x73\x74\x73\x2e"));}return ($result);}sub 
NXHostsManager::getClientRedirectBeforeAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x1567+ 825-0x189f)));}sub 
NXHostsManager::getClientRedirectAfterAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x0c54+ 3895-0x1b8b)));}sub 
NXHostsManager::__getClientRedirect{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $authbeforelogin=shift (@_));my (@hostTab);my (@ipTab);(my $all
=(0x0d16+ 2833-0x1827));if (NXLicense::isNotRedirectFeature ()){return (
(0x023d+ 3332-0x0f41));}(my (@hostlist)=__list ());foreach my $hostline (
@hostlist){($hostline=~ s/\n//g );(my (@line)=split ( /,/ ,$hostline,
(0x05b0+ 5002-0x193a)));if ((($line[(0x1132+ 2463-0x1ad1)]eq "\x2a")or ($line[
(0x0587+ 8164-0x256b)]eq "\x2a\x2e\x2a\x2e\x2a\x2e\x2a"))){if (((
$authbeforelogin and ($line[(0x05c9+ 6163-0x1dda)]eq "\x62\x65\x66\x6f\x72\x65")
)or ((not ($authbeforelogin))and ($line[(0x0ce9+ 610-0x0f49)]eq 
"\x61\x66\x74\x65\x72")))){($all=$line[(0x1e25+ 1420-0x23b0)]);}}elsif (($line[
(0x10c8+ 5592-0x26a0)]=~ /^[0-9\*\.]{1,15}$/ )){if ((($authbeforelogin and (
$line[(0x0ffd+ 5659-0x2616)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not (
$authbeforelogin))and ($line[(0x07c5+ 2716-0x125f)]eq "\x61\x66\x74\x65\x72"))))
{push (@ipTab,[$line[(0x0770+ 2778-0x124a)],$line[(0x14ea+ 834-0x182b)],$line[
(0x0311+ 5804-0x19bb)]]);}}else{if ((($authbeforelogin and ($line[
(0x13bf+ 2752-0x1e7d)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin)
)and ($line[(0x1b17+  87-0x1b6c)]eq "\x61\x66\x74\x65\x72")))){push (@hostTab,[
$line[(0x177b+ 2066-0x1f8d)],$line[(0x0d2a+ 2285-0x1616)],$line[
(0x023c+ 3469-0x0fc7)]]);}}}(my $regEx=(""));foreach my $ipLine (@ipTab){(my (
@pieces)=split ( /\./ ,@{$ipLine;}[(0x084a+ 2628-0x128e)],(-
(0x0a10+ 6461-0x234c))));(my $piecesCount=scalar (@pieces));($regEx=@{$ipLine;}[
(0x0dfd+ 1262-0x12eb)]);if (($piecesCount<(0x0681+ 1770-0x0d67))){if (($pieces[
(0x0908+ 3865-0x1821)]=~ /^\*/ )){($regEx=("\x2e\x7b\x30\x2c\x7d".$regEx));}if (
($pieces[$piecesCount-(0x08b6+  35-0x08d8)]=~ /\*$/ )){($regEx.=
"\x2e\x7b\x30\x2c\x7d");}}($regEx=~ s/\*/(|[0-9]|[0-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])/g )
;if (($client=~ /^($regEx)$/ )){return (@{$ipLine;}[(0x0a38+ 3503-0x17e6)]);}}
foreach my $hostLine (@hostTab){(my (@ipdata)=split ( /\./ ,$client,
(0x0049+ 9580-0x25b5)));(my $ippacked=pack ("\x43\x34",@ipdata));(my $host=
gethostbyaddr ($ippacked,(0x04c4+ 722-0x0794)));if ((@{$hostLine;}[
(0x034a+ 979-0x071d)]=~ /^\*/ )){(@{$hostLine;}[(0x0963+ 4520-0x1b0b)]=~ s/^\*// )
;}else{(@{$hostLine;}[(0x0684+ 6750-0x20e2)]=("\x5e".@{$hostLine;}[
(0x0bf7+ 2786-0x16d9)]));}if ((@{$hostLine;}[(0x0090+ 5861-0x1775)]=~ /\*$/ )){(
@{$hostLine;}[(0x10f4+ 2457-0x1a8d)]=~ s/\*$// );}else{(@{$hostLine;}[
(0x015f+ 4017-0x1110)]=(@{$hostLine;}[(0x0652+ 6651-0x204d)]."\x24"));}if ((
$host=~ @{$hostLine;}[0] )){return (@{$hostLine;}[(0x023a+ 5223-0x16a0)]);}}if (
$all){return ($all);}Logger::debug (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x66\x6f\x75\x6e\x64\x20\x63\x6c\x69\x65\x6e\x74\x20\x49\x50\x3a\x20\x27"
.$client)."\x27\x20\x69\x6e\x20\x68\x6f\x73\x74\x73\x2e\x64\x62\x2e"));return (
(0x221b+ 466-0x23ed));}package NXHostsManager;no warnings;
NXMsg::register_response (
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",(0x1d52+ 1344-0x2203));
"\x3f\x3f\x3f";
